# pl-ci-cd

Continuous integration and continuous deployment of python projects.

## Installation

Install ruff, pyright, pytest, and pytest-cov in your uv project.

(Optional) Install pl-ci-cd as a CLI tool:

```bash
uv tool install pl-ci-cd
```

## Usage

Run with uvx:

```bash
uvx --from pl-ci-cd check
```

Run as a CLI tool:

```bash
check
```

## License

Licensed under the Apache License 2.0. See [LICENSE](./LICENSE).
